@@ -4,7 +4,8 @@
 
 from .cvss2 import CVSS2
 from .cvss3 import CVSS3
-from .exceptions import CVSS2Error, CVSS3Error, CVSSError
+from .cvss4 import CVSS4
+from .exceptions import CVSS2Error, CVSS3Error, CVSS4Error, CVSSError
 from .interactive import ask_interactively
 
-__version__ = "2.6"
+__version__ = "3.2"
